@@ -30,8 +30,8 @@
 #' by residual variances (D), the sum of the tagret nodes perturbation
 #' (i.e., group effect) accumulation from source nodes (A), and the sum
 #' of the source nodes perturbation emission towards target nodes (E).
-#' For undirected graphs, the sum of group effects, adjusted
-#' by residual variances (D), will be estimated.
+#' For undirected graphs, the sum of group effects (D), adjusted
+#' by residual variances, will be estimated.
 #' @param g A list of pathways to be tested.
 #' @param data A matrix or data.frame. Rows correspond to subjects, and
 #' columns to graph nodes (variables).
@@ -41,8 +41,7 @@
 #' @param method Multiple testing correction method. One of the values
 #' available in \code{\link[stats]{p.adjust}}. By default, method is set
 #' to "BH" (i.e., Benjamini-Hochberg correction).
-#' @param alpha Gene set test significance level. Alpha is set to 0.05
-#' by default.
+#' @param alpha Gene set test significance level (default = 0.05).
 #' @param n_rep Number of randomization replicates (default = 1000).
 #' @param ... Currently ignored.
 #'
@@ -76,24 +75,22 @@
 #'
 #' \dontrun{
 #'
-#' # Install data examples, reference networks, and pathways:
-#' # devtools::install_github("fernandoPalluzzi/SEMdata")
-#' library(SEMdata)
+#' # Nonparanormal(npn) transformation
+
 #' library(huge)
-#'
 #' als.npn <- huge.npn(alsData$exprs)
 #'
-#' #selection of FTD pathways from KEGG
+#' # Selection of FTD pathways from kegg.pathways.Rdata
 #'
 #' paths.name <- c("MAPK signaling pathway",
 #'                 "Protein processing in endoplasmic reticulum",
 #'                 "Endocytosis",
 #'                 "Wnt signaling pathway",
-#'                 "Notch signaling pathway",
 #'                 "Neurotrophin signaling pathway",
-#'                 "Amyotrophic lateral sclerosis (ALS)")
+#'                 "Amyotrophic lateral sclerosis")
 #' 
 #' j <- which(names(kegg.pathways) %in% paths.name)
+#'
 #' GSA <- SEMgsa(kegg.pathways[j], als.npn, alsData$group,
 #'               method = "bonferroni", alpha = 0.05,
 #'               n_rep = 1000)
@@ -118,6 +115,7 @@ SEMgsa <- function(g = list(), data, group, method = "BH", alpha = 0.05,
 		quiet(ig <- properties(g[[k]])[[1]])
 
 		# SEM fitting
+		fit <- NULL
 		err <- paste(" ValueError: none of pathway #", k,
 		             " variables are present in the dataset.\n",
 		             sep = "")
@@ -186,15 +184,10 @@ SEMgsa <- function(g = list(), data, group, method = "BH", alpha = 0.05,
 #'
 #' @examples
 #'
-#' # Extract from graphite the "Steroid biosynthesis" pathway:
-#'
-#' library(graphite)
-#' humanKegg <- pathways("hsapiens", "kegg")
-#' p <- humanKegg[["Steroid biosynthesis"]]
-#' g <- pathwayGraph(p)
-#' graph::nodes(g) <- gsub("ENTREZID:","",graph::nodes(g))
-#'
-#' properties(graph_from_graphnel(g))
+#' # Extract the "Type II diabetes mellitus" pathway:
+#' g <- kegg.pathways[["Type II diabetes mellitus"]]
+#' properties(g)
+#' summary(g)
 #'
 properties <- function(graph, data = NULL, ...)
 {
@@ -269,7 +262,7 @@ mergeGraph <- function(g = list(), gref = NULL, gnet = NULL, verbose = FALSE,
 #' Rgraphwiz.
 #'
 #' @param graph An igraph or graphNEL object.
-#' @param l any layout supported by \code{Rgraphviz}. It can be one among:
+#' @param l Any layout supported by \code{Rgraphviz}. It can be one among:
 #' "dot" (default), "neato", "circo", "fdp", "osage", "twopi".
 #' @param main Plot main title (by default, no title is added).
 #' @param cex.main Main title size (default = 1).
@@ -315,16 +308,21 @@ gplot <- function(graph, l = "dot", main = "", cex.main = 1, font.main = 1,
 	g <- as_graphnel(graph)
 
 	vcol <- V(graph)$color
+	vshape <- V(graph)$shape
 	vsize <- V(graph)$size
 	vlab <- V(graph)$label
 	ecol <- E(graph)$color
 	elwd <- E(graph)$width
 	elab <- E(graph)$label
-
+	
 	if (length(vcol) > 0) {
 		names(vcol) <- V(graph)$name
 		vcol <- vcol[graph::nodes(g)]
 	}
+	if (length(vshape) > 0) {
+		names(vshape) <- V(graph)$name
+		vshape <- vshape[graph::nodes(g)]
+	}
 	if (length(vsize) > 0) {
 		names(vsize) <- V(graph)$name
 		vsize <- 10*vsize[graph::nodes(g)]
@@ -336,6 +334,10 @@ gplot <- function(graph, l = "dot", main = "", cex.main = 1, font.main = 1,
 		names(vlab) <- V(graph)$name
 		vlab <- vlab[graph::nodes(g)]
 	}
+	if (length(color) > 1) {
+		names(color) <- V(graph)$name
+		color <- color[graph::nodes(g)]
+	}
 	if (length(ecol) > 0) {
 		names(ecol) <- gsub("\\|", "~", attr(E(graph), "vnames"))
 		ecol <- ecol[graph::edgeNames(g, recipEdges = "distinct")]
@@ -367,7 +369,7 @@ gplot <- function(graph, l = "dot", main = "", cex.main = 1, font.main = 1,
 	                                label = vlab, lwd = lwd,
 	                                textCol = color.txt,
 	                                fontsize = fontsize, cex = cex,
-	                                shape = shape, width = w, height = h)
+	                                shape = vshape, width = w, height = h)
 	graph::edgeRenderInfo(g) <- list(col = ecol, lty = 1, lwd = elwd)
 	graph::graphRenderInfo(g) <- list(main = main, cex.main = cex.main,
 	                                  font.main = font.main)
@@ -1037,17 +1039,17 @@ Brown.test <- function(x, p, theta = NULL, tail = "both", ...)
 #' \code{\link[SEMgraph]{extendGraph}} to find new indirect paths (i.e.,
 #' inferred directed connections that may hide new mediators). New
 #' interactions and mediators will be searched and imported from the
-#' reference network (argument gnet, see above). Both DAG and extended
-#' graph complexity can be controlled with beta > 0 and d > 1 arguments,
-#' respectively (see below). The term "outer" means that new model mediator
-#' variables are imported from an external resource (i.e., the reference
-#' network).
+#' reference network (argument \code{gnet}, see above). Both DAG and
+#' extended graph complexity can be controlled with \code{beta} > 0 and
+#' \code{d} > 1 arguments, respectively (see below). The term "outer"
+#' means that new model mediator variables are imported from an external
+#' resource (i.e., the reference network).
 #' \item "inner". This strategy is analogous to the "outer" one,
 #' but disables external mediator search. In other words, new indirect
 #' paths are generated by adding new interactions of the input model, so
 #' that mediators will be nodes already present in the input graph. The
 #' reference network is still used to validate new model paths. Also in
-#' this case, beta > 0 and d > 1 are used.
+#' this case, \code{beta} > 0 and \code{d} > 1 are used.
 #' \item "direct". The input graph structure is improved through direct
 #' (i.e., adjacent) link search, followed by interaction validation and
 #' import from the reference network, with no mediators
@@ -1055,26 +1057,28 @@ Brown.test <- function(x, p, theta = NULL, tail = "both", ...)
 #' \item "basic" (default). While the previous strategies rely on the
 #' input graph and the reference network to integrate knowledge to the
 #' final model, the "basic" strategy is data-driven. The input graph is
-#' needed to define the topological order. The argument gnet is set
-#' to NULL (i.e., no reference network is needed) and argument \code{d = 0}.
-#' Model complexity can be still controlled by setting beta > 0.
+#' needed to define the topological order. The argument \code{gnet} is
+#' set to NULL (i.e., no reference network is needed) and argument
+#' \code{d = 0}. Model complexity can be still controlled by setting
+#' \code{beta} > 0.
 #' }
 #' @param beta Numeric value. Minimum absolute LASSO beta coefficient for
 #' a new interaction to be retained in the estimated DAG backbone. Lower
-#' beta values correspond to more complex DAGs. By default, beta
-#' is set to 0 (i.e., maximum complexity).
+#' \code{beta} values correspond to more complex DAGs.
+#' By default, \code{beta} is set to 0 (i.e., maximum complexity).
 #' @param d Maximum allowed geodesic distance for directed or undirected
 #' shortest path search. A distance \code{d = 0} disables shortest path
-#' search (fixed in search = "basic"), while \code{d = 1} (fixed in
-#' \code{search = "direct"}) only search for directed links (i.e., no
-#' mediators are allowed).
-#' A distance d > 1 (defaults to \code{d = 2} for "outer" and "inner"
-#' strategies), will search for shortest paths with at most d - 1 mediators
-#' between nodes sharing a significant estimated interaction.
+#' search (fixed in \code{search = "basic"}), while \code{d = 1} 
+#' (fixed in \code{search = "direct"}) only search for directed links
+#' (i.e., no mediators are allowed).
+#' A distance \code{d} > 1 (defaults to \code{d = 2} for "outer" and
+#' "inner" strategies), will search for shortest paths with at most
+#' \code{d} - 1 mediators between nodes sharing a significant estimated
+#' interaction.
 #' Connectors are imported from the reference interactome, as specified
 #' by the argument gnet. If the edges of the reference interactome are
-#' weighted by P-value, as defined by the E(graph)$pv attribute, the
-#' shortest path with the smallest sum of weights will be chosen (e.g.,
+#' weighted by P-value, as defined by the \code{E(graph)$pv} attribute,
+#' the shortest path with the smallest sum of weights will be chosen (e.g.,
 #' see \code{\link[SEMgraph]{weightGraph}} for graph weighting options).
 #' @param alpha Significance level for false discovery rate (FDR) used
 #' for either local d-separation tests (below \code{limit}) or conditional
@@ -1102,9 +1106,10 @@ Brown.test <- function(x, p, theta = NULL, tail = "both", ...)
 #' knowledge-assisted model improvement. The last one does not require
 #' any reference and the output model structure will be completely
 #' determined by data.
-#' Output model complexity can be limited using arguments d and beta.
-#' While d is fixed to 0 or 1 in \code{"basic"} or \code{"direct"},
-#' respectively; we suggest starting with \code{d = 2} (only one mediator)
+#' Output model complexity can be limited using arguments \code{d} and
+#' \code{beta}.
+#' While d is fixed to 0 or 1 in "basic" or "direct", respectively;
+#' we suggest starting with \code{d = 2} (only one mediator)
 #' for the other two strategies.
 #' For knowledge-based strategies, we suggest to to start with
 #' \code{beta = 0.1}. Then, beta can be relaxed (0 to < 0.1) to improve
@@ -1113,7 +1118,8 @@ Brown.test <- function(x, p, theta = NULL, tail = "both", ...)
 #' The beta value can be relaxed until a good model fit is obtained.
 #' Argument alpha determines the extent of data adjustment: lower alpha
 #' values for FDR correction correspond to a smaller number of significant
-#' confounding factors, hence a weaker correction (default alpha = 0.05).
+#' confounding factors, hence a weaker correction
+#' (default \code{alpha = 0.05}).
 #'
 #' @import lavaan
 #' @import igraph
